@@ -693,6 +693,13 @@ sub WritableAttributes {
 Takes a field name and returns that field's value. Subclasses should never
 override __Value.
 
+This method doesn't do any extra work to modify or normalize the encoding of
+the field's value. Different databases and database drivers have different ways
+of handling encoding on returned values. For example, L<DBD::Oracle> automatically
+marks values as UTF-8 if C<NLS_NCHAR> is set to C<AL32UTF8>. Review the documentation
+for the database driver you are using and test to make sure you handle special
+characters in returned content.
+
 =cut
 
 
@@ -853,10 +860,14 @@ sub __Set {
         # Support for databases which don't deal with LOBs automatically
         my $ca = $self->_ClassAccessible();
         my $key = $args{'Column'};
-        if ( $ca->{$key}->{'type'} =~ /^(text|longtext|clob|blob|lob)$/i ) {
+        if ( ( $ca->{$key}->{'type'} // '' ) =~ /^(text|longtext|clob|longblob|blob|lob)$/i ) {
             my $bhash = $self->_Handle->BLOBParams( $key, $ca->{$key}->{'type'} );
-            $bhash->{'value'} = $args{'Value'};
-            $args{'Value'} = $bhash;
+            if ( ref($bhash) eq 'HASH'
+                && ( ( defined $args{'Value'} && length $args{'Value'} ) || $self->_Handle->HasSupportForEmptyString ) )
+            {
+                $bhash->{'value'} = $args{'Value'};
+                $args{'Value'} = $bhash;
+            }
         }
     }
 
@@ -1302,11 +1313,15 @@ sub Create {
         my $ca = $self->_ClassAccessible();
         foreach $key ( keys %attribs ) {
             my $type = $ca->{$key}->{'type'};
-            next unless $type && $type =~ /^(text|longtext|clob|blob|lob)$/i;
+            next unless $type && $type =~ /^(text|longtext|clob|blob|lob|longblob)$/i;
 
             my $bhash = $self->_Handle->BLOBParams( $key, $type );
-            $bhash->{'value'} = $attribs{$key};
-            $attribs{$key} = $bhash;
+            if ( ref($bhash) eq 'HASH'
+                && ( ( defined $attribs{$key} && length $attribs{$key} ) || $self->_Handle->HasSupportForEmptyString ) )
+            {
+                $bhash->{'value'} = $attribs{$key};
+                $attribs{$key} = $bhash;
+            }
         }
     }
     return ( $self->_Handle->Insert( $self->Table, %attribs ) );
@@ -1410,23 +1425,3 @@ if( eval { require capitalization } ) {
 }
 
 1;
-
-__END__
-
-
-
-=head1 AUTHOR
-
-Jesse Vincent, <jesse@fsck.com>
-
-Enhancements by Ivan Kohler, <ivan-rt@420.am>
-
-Docs by Matt Knopp <mhat@netlag.com>
-
-=head1 SEE ALSO
-
-L<DBIx::SearchBuilder>
-
-=cut
-
-
